@@ -65,6 +65,7 @@ def get_model(
     k=6,
     base_lr=1e-4,
     max_lr=6e-3,
+    save=True,
 ):
     """Get a CrabNet model with default parameters set.
     #TODO: flesh out descriptions of parameters, as well as feasible min/max bounds
@@ -137,7 +138,8 @@ def get_model(
         [description], by default 10
     criterion : torch.nn Module, optional
         Or in other words the loss function (e.g. BCEWithLogitsLoss for classification
-        or RobustL1 for regression), by default None
+        or RobustL1 for regression), by default None. Possible values are
+        `BCEWithLogitsLoss`, `RobustL1`, and `RobustL2`.
     lr : float, optional
         Learning rate, by default 1e-3
     betas : tuple, optional
@@ -158,6 +160,8 @@ def get_model(
         Base learning rate, by default 1e-4
     max_lr : float, optional
         Max learning rate, by default 6e-3
+    save : bool, optional
+        Whether to save the network or not, by default True.
 
     Returns
     -------
@@ -260,10 +264,12 @@ def get_model(
         k=k,
         base_lr=base_lr,
         max_lr=max_lr,
+        verbose=verbose,
     )
 
     # Save the network (saved as f"{model_name}.pth")
-    model.save_network()
+    if save:
+        model.save_network(verbose=verbose)
     return model
 
 
@@ -415,6 +421,8 @@ def main(
         model, mat_prop, classification, train_data, verbose=False
     )
     if val_data is not None:
+        if isinstance(val_data, pd.DataFrame):
+            val_data[val_data.target.isnull()] = 0
         if verbose:
             print("-----------------------------------------------------")
             print("calculating val mae")
